======================================================================
FEEL-IT: Emotion and Sentiment Classification for the Italian Language
======================================================================


.. image:: https://img.shields.io/pypi/v/feel_it.svg
        :target: https://pypi.python.org/pypi/feel_it

.. image:: https://readthedocs.org/projects/feel-it/badge/?version=latest
        :target: https://feel-it.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status






Abstract
--------

Sentiment analysis is a common task to understand people's reactions online. Still, we often need more nuanced information: is the post negative because the user is angry or because they are sad?

An abundance of approaches has been introduced for tackling both tasks. However, at least for Italian, they all treat only one of the tasks at a time. We introduce FEEL-IT, a novel benchmark corpus of Italian Twitter posts annotated with four basic emotions: anger, fear, joy, sadness. By collapsing them, we can also do sentiment analysis. We evaluate our corpus on benchmark datasets for both emotion and sentiment classification, obtaining competitive results.

We release an open-source Python library, so researchers can use a model trained on FEEL-IT for inferring both sentiments and emotions from Italian text.


* Free software: MIT license
* Documentation: https://feel-it.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
